Type Alias bevy_utils::BoxedFuture

source ·
pub type BoxedFuture<'a, T> = Pin<Box<dyn Future<Output = T> + Send + 'a>>;
An owned and dynamically typed Future used when you can’t statically type your result or need to add some indirection.

Aliased Type

struct BoxedFuture<'a, T> { /* private fields */ }