Type Alias bevy_utils::StableHashMap
source · pub type StableHashMap<K, V> = HashMap<K, V, FixedState>;Expand description
A stable hash map implementing aHash, a high speed keyed hashing algorithm intended for use in in-memory hashmaps.
Unlike HashMap this has an iteration order that only depends on the order
of insertions and deletions and not a random source.
aHash is designed for performance and is NOT cryptographically secure.
Aliased Type
struct StableHashMap<K, V> { /* private fields */ }